| statswalesr-package | R Documentation |
Download data from the 'StatsWales' public API (https://api.stats.gov.wales/v2) into R. Provides functions to list, search, and browse datasets by topic, retrieve data with optional filtering, sorting, and pivoting, and download datasets as CSV or Excel files.
Maintainer: Jamie Ralph jamesryanralph@outlook.com
Authors:
Jamie Ralph jamesryanralph@outlook.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.