statswales_get_dataset: Retrieves a dataset from the StatsWales OData API
Description
statswales_get_dataset returns a dataframe from
StatsWales using a dataset id. The
print_progress argument can be set to TRUE to keep track of
progress when extracting a large dataset.
Usage
statswales_get_dataset(id, print_progress = FALSE, language = "english")
Arguments
id
A dataset id. Must be a single string.
print_progress
logical. Should progress be printed in the console?
language
A string. Returns the dataset in either English ('english') or Welsh ('welsh').
The default is English.
Value
If the dataset id is valid, the function will return the requested
dataset in a dataframe. If the id is not valid, the function will return
an error.