powered by
statswales_get_metadata returns a dataframe containing metadata from StatsWales using a dataset id.
statswales_get_metadata
statswales_get_metadata(id, language = "english")
A dataset id as a string
A string. Returns the metadata in either English ('english') or Welsh ('welsh'). The default is English.
If the dataset id is valid, the output will be the requested metadata in a dataframe. If the id is not valid, the function will return an HTTP error.
# NOT RUN { metadata <- statswales_get_metadata("hlth0515") # }
Run the code above in your browser using DataLab