Returns a data frame of all published datasets available from the StatsWales public API. All pages are fetched automatically, so the full catalogue is returned.
Returns a data frame of all published datasets available from the StatsWales public API. All pages are fetched automatically, so the full catalogue is returned.