statswales_list_topics: List top-level topics

View source: R/statswales_list_topics.R

statswales_list_topicsR Documentation

List top-level topics

Description

Returns a data frame of all top-level topics that have at least one published dataset tagged against them.

Usage

statswales_list_topics(lang = "en-gb")

Arguments

lang

Language for returned text. One of "en-gb" (default), "en", "cy-gb", or "cy".

Value

A data frame with columns id, path, name, name_en, and name_cy. Returns NULL if the request fails.

Examples

## Not run: 
topics <- statswales_list_topics()

## End(Not run)


statswalesr documentation built on July 12, 2026, 5:06 p.m.