View source: R/statswales_list_topics.R
| statswales_list_topics | R Documentation |
Returns a data frame of all top-level topics that have at least one published dataset tagged against them.
statswales_list_topics(lang = "en-gb")
lang |
Language for returned text. One of |
A data frame with columns id, path, name, name_en, and
name_cy. Returns NULL if the request fails.
## Not run:
topics <- statswales_list_topics()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.